@@ -31,9 +31,8 @@ class CircularDependencyError(ValueError):
     """
 
     def __init__(self, data):
-        err = 'Circular dependencies exist among these items: {{{}}}'.format(
-            ', '.join(
-                '{!r}:{!r}'.format(key, value) for key, value in data.items()))
+        items = ', '.join(f'{key!r}:{value!r}' for key, value in data.items())
+        err = f'Circular dependencies exist among these items: {items}'
         super().__init__(err)
         self.data = data
 
