@@ -75,8 +75,19 @@ class Bool(Type):
             return True
         if value == 'false':
             return False
+        if value == 'NULL':
+            return None
         raise AttributeError(f"'Bool' type has no value '{value}'")
 
+    @staticmethod
+    def sql(value):
+        if value:
+            return 'TRUE'
+        if value is False:
+            return 'FALSE'
+        # Must be None
+        return 'NULL'
+
 
 # Deprecating
 Boolean = Bool
