@@ -92,7 +92,7 @@ class Relationship(Resource):
         links = {
             'self':
                 self.path(),
-            'related': (f'/{self.collection.name}/{self.id.name}'
+            'related': (f'/resources/{self.collection.name}/{self.id.name}'
                         f'/{self.relationship.name}')
         }
         return document_response(await self.to_document(query=query,
@@ -171,12 +171,13 @@ class Relationship(Resource):
         record = await connection.fetchrow(stmt, self.id.number)
         if record is None:
             raise ErrorsException([
-                ResourceNotFoundError(f'/{self.collection.name}/{self.id.name}')
+                ResourceNotFoundError(
+                    f'/resources/{self.collection.name}/{self.id.name}')
             ])
 
     def path(self):
         """Creates the path to the relationship."""
-        return (f'/{self.collection.name}/{self.id.name}/'
+        return (f'/resources/{self.collection.name}/{self.id.name}/'
                 f'relationships/{self.relationship.name}')
 
 
@@ -267,7 +268,8 @@ class OneToOneLocalRelationship(ToOneRelationship):
             record = await connection.fetchrow(stmt, self.id.number)
         if record is None:
             raise ErrorsException([
-                ResourceNotFoundError(f'/{self.collection.name}/{self.id.name}')
+                ResourceNotFoundError(
+                    f'/resources/{self.collection.name}/{self.id.name}')
             ])
         record_id = record[0]
         if record_id is None:
@@ -295,7 +297,7 @@ class OneToOneLocalRelationship(ToOneRelationship):
             if result == 'UPDATE 0':
                 raise ErrorsException([
                     ResourceNotFoundError(
-                        f'/{self.collection.name}/{self.id.name}')
+                        f'/resources/{self.collection.name}/{self.id.name}')
                 ])
         except UniqueViolationError as exc:
             raise ErrorsException([DocumentDataRelationshipConflictError()
@@ -367,7 +369,8 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                     except ForeignKeyViolationError as exc:
                         raise ErrorsException([
                             ResourceNotFoundError(
-                                f'/{self.collection.name}/{self.id.name}')
+                                f'/resources/{self.collection.name}'
+                                f'/{self.id.name}')
                         ]) from exc
 
 
@@ -385,7 +388,8 @@ class ManyToOneRelationship(ToOneRelationship):
             record = await connection.fetchrow(stmt, self.id.number)
         if record is None:
             raise ErrorsException([
-                ResourceNotFoundError(f'/{self.collection.name}/{self.id.name}')
+                ResourceNotFoundError(
+                    f'/resources/{self.collection.name}/{self.id.name}')
             ])
         record_id = record[0]
         if record_id is None:
@@ -412,7 +416,7 @@ class ManyToOneRelationship(ToOneRelationship):
             if result == 'UPDATE 0':
                 raise ErrorsException([
                     ResourceNotFoundError(
-                        f'/{self.collection.name}/{self.id.name}')
+                        f'/resources/{self.collection.name}/{self.id.name}')
                 ])
         except ForeignKeyViolationError as exc:
             raise ErrorsException([
@@ -563,7 +567,8 @@ class OneToManyRelationship(ToManyRelationship):
                     except ForeignKeyViolationError as exc:
                         raise ErrorsException([
                             ResourceNotFoundError(
-                                f'/{self.collection.name}/{self.id.name}')
+                                f'/resources/{self.collection.name}'
+                                f'/{self.id.name}')
                         ]) from exc
                 else:
                     await self.verify_id_exists(connection)
@@ -584,7 +589,8 @@ class OneToManyRelationship(ToManyRelationship):
                     except ForeignKeyViolationError as exc:
                         raise ErrorsException([
                             ResourceNotFoundError(
-                                f'/{self.collection.name}/{self.id.name}')
+                                f'/resources/{self.collection.name}'
+                                f'/{self.id.name}')
                         ]) from exc
                     if result != f'UPDATE {len(data_ids)}':
                         stmt_verify = (
@@ -724,7 +730,8 @@ class ManyToManyRelationship(ToManyRelationship):
         groups = RE_FOREIGN_KEY_VIOLATION_ERROR_DETAIL.match(detail).groups()
         if groups[0] == self.relationship.lafkey:
             raise ErrorsException([
-                ResourceNotFoundError(f'/{self.collection.name}/{self.id.name}')
+                ResourceNotFoundError(
+                    f'/resources/{self.collection.name}/{self.id.name}')
             ])
         # groups[0] == self.relationship.rafkey
 
@@ -856,21 +863,22 @@ def make_relationship(collection_name, id_name, relationship_name):
     try:
         collection = Collection.by_name[collection_name]
     except KeyError as exc:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
-                              ]) from exc
+        raise ErrorsException(
+            [ResourceNotFoundError(f'/resources/{collection_name}')]) from exc
 
     try:
         id_ = IdValue(id_name)
     except ValueError as exc:
         raise ErrorsException([
-            ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')
+            ResourceNotFoundMalformedIdError(
+                f'/resources/{collection_name}/{id_name}')
         ]) from exc
 
     try:
         relationship = getattr(collection.table.___, relationship_name)
     except AttributeError as exc:
         raise ErrorsException([
-            ResourceNotFoundError(f'/{collection_name}/{id_name}/'
+            ResourceNotFoundError(f'/resources/{collection_name}/{id_name}/'
                                   f'relationships/{relationship_name}')
         ]) from exc
 
